#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dmaps_interfaces.activity import Activity
from pycatia.product_structure_interfaces.product import Product


class Task(Activity):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     DMAPSInterfaces.Activity
                |                         Task
                | 
                | Represents the Task of a resource.
                | 
                | Role: Task is the object used to access and manage the attributes of the
                | task.
                | The following code snippet can be used to obtain the Task from the Resource
                | program manager.
                | 
                |    Dim objResourceProgramManager As ResourceProgramManager
                |    Dim oTask As Task
                |    
                |    objResourceProgramManager.GetTask  "RobotTask.1", oTask
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.task = com_object

    def get_name(self, o_name: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetName(CATBSTR oName)
                | 
                |     Get the name of the Task
                | 
                |     Parameters:
                | 
                |         oName
                |             The user defined name of the Task. 
                | 
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |         S_OK
                |             The name of the task was corrrectly retrieved
                |         E_FAIL
                |             The name of the task was not corrrectly retrieved
                | 
                |         Example:
                |             The following example get the name of the task.
                | 
                |                Dim objTask As Task
                |                Dim strTaskName As String
                |                ..
                |                objTask.GetName strTaskName

        :param str o_name:
        :rtype: None
        """
        return self.task.GetName(o_name)

    def get_resource(self, o_res: Product) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetResource(Product oRes)
                | 
                |     Gets the Owning Resource
                | 
                |     Parameters:
                | 
                |         oRes
                |             The Owning Resource. 
                | 
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |         S_OK
                |             The owning resource was corrrectly retrieved
                |         E_FAIL
                |             The owning resource was not corrrectly retrieved
                | 
                |         Example:
                |             The following example retrieves the owning resource of the
                |             task.
                | 
                |                Dim objTask As Task   
                |                Dim objRobot as Product
                |                ..
                |                objTask.GetResource objRobot

        :param Product o_res:
        :rtype: None
        """
        return self.task.GetResource(o_res.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_resource'
        # # vba_code = """
        # # Public Function get_resource(task)
        # #     Dim oRes (2)
        # #     task.GetResource oRes
        # #     get_resource = oRes
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_name(self, i_name: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetName(CATBSTR iName)
                | 
                |     Set the name of the task
                | 
                |     Parameters:
                | 
                |         iName
                |             The user defined name of the Task. 
                | 
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |         S_OK
                |             The name of the task was set corrrectly 
                |         E_FAIL
                |             The name of the task was not set corrrectly 
                | 
                |         Example:
                |             The following example set the name of the task.
                | 
                |                Dim objTask As Task     
                |                ..
                |                objTask.SetName("RobotTask.2")

        :param str i_name:
        :rtype: None
        """
        return self.task.SetName(i_name)

    def __repr__(self):
        return f'Task(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_sch_platform_interfaces.sch_list_of_bst_rs import SchListOfBSTRs
from pycatia.cat_sch_platform_interfaces.sch_list_of_doubles import SchListOfDoubles
from pycatia.cat_sch_platform_interfaces.sch_list_of_longs import SchListOfLongs
from pycatia.cat_sch_platform_interfaces.sch_list_of_objects import SchListOfObjects
from pycatia.system_interfaces.any_object import AnyObject


class SchTempListFactory(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SchTempListFactory
                | 
                | Create temporary (non-persistent) lists to be used in VB
                | environment.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sch_temp_list_factory = com_object

    def create_list_of_bst_rs(self) -> SchListOfBSTRs:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func CreateListOfBSTRs() As SchListOfBSTRs
                | 
                |     This method returns a new empty list of strings.
                | 
                |     Returns:
                |         a empty list of strings. 
                |     Example:
                | 
                |           This example illustrates how to create a new empty list of
                |           strings.
                |          
                |          Dim SchListFact As SchTempListFactory
                |          Dim NewList As SchListOfBSTRs
                |          Set NewList = SchListFact.CreateListOfBSTRs

        :rtype: SchListOfBSTRs
        """
        return SchListOfBSTRs(self.sch_temp_list_factory.CreateListOfBSTRs())

    def create_list_of_doubles(self) -> SchListOfDoubles:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func CreateListOfDoubles() As SchListOfDoubles
                | 
                |     This method returns a new empty list of doubles.
                | 
                |     Returns:
                |         a empty list of doubles. 
                |
                |     Example:
                | 
                |           This example illustrates how to create a new empty list of
                |           doubles.
                |          
                |          Dim SchListFact As SchTempListFactory
                |          Dim NewList As SchListOfDoubles
                |          Set NewList = SchListFact.CreateListOfDoubles

        :rtype: SchListOfDoubles
        """
        return SchListOfDoubles(self.sch_temp_list_factory.CreateListOfDoubles())

    def create_list_of_longs(self) -> SchListOfLongs:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func CreateListOfLongs() As SchListOfLongs
                | 
                |     This method returns a new empty list of long integers.
                | 
                |     Returns:
                |         a empty list of long integers. 
                |     Example:
                | 
                |           This example illustrates how to create a new empty list of long
                |           integers.
                |
                |          Dim SchListFact As SchTempListFactory
                |          Dim NewList As SchListOfLongs
                |          Set NewList = SchListFact.CreateListOfLongs

        :rtype: SchListOfLongs
        """
        return SchListOfLongs(self.sch_temp_list_factory.CreateListOfLongs())

    def create_list_of_objects(self) -> SchListOfObjects:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func CreateListOfObjects() As SchListOfObjects
                | 
                |     This method returns a new empty list of objects.
                | 
                |     Returns:
                |         a empty list of objects. 
                |
                |     Example:
                | 
                |           This example illustrates how to create a new empty list of
                |           objects.
                |
                |          Dim SchListFact As SchTempListFactory
                |          Dim NewList As SchListOfObjects
                |          Set NewList = SchListFact.CreateListOfObjects

        :rtype: SchListOfObjects
        """
        return SchListOfObjects(self.sch_temp_list_factory.CreateListOfObjects())

    def __repr__(self):
        return f'SchTempListFactory(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.funct_system_interfaces.functional_element import FunctionalElement
from pycatia.system_interfaces.any_object import AnyObject


class FunctionalFacet(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     FunctionalFacet
                | 
                | The interface to access a Functional Facet.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.functional_facet = com_object

    @property
    def functional_element(self) -> FunctionalElement:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property FunctionalElement() As FunctionalElement (Read
                | Only)
                | 
                |     Get the Functional Element owning the Facet.

        :rtype: FunctionalElement
        """

        return FunctionalElement(self.functional_facet.FunctionalElement)

    def free(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Free()
                | 
                |     Free the resources allocated by the Facet.

        :rtype: None
        """
        return self.functional_facet.Free()

    def init(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Init()
                | 
                |     Init resources for the Facet.

        :rtype: None
        """
        return self.functional_facet.Init()

    def __repr__(self):
        return f'FunctionalFacet(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.knowledge_interfaces.parameter import Parameter


class EnumParam(Parameter):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     KnowledgeInterfaces.Parameter
                |                         EnumParam
                | 
                | Represents the enum parameter.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.enum_param = com_object

    @property
    def value_enum(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property ValueEnum() As CATBSTR
                | 
                |     Returns or sets the value of the EnumParameter object. Units are expressed
                |     in the IS unit system, except for lengths expressed in millimeters, and angles
                |     expressed in decimal degrees.
                | 
                |     Example:
                |         This example sets the param1 value to 1 if its value is greater than
                |         2.5:
                | 
                |          If (density.Value > 2.5)  Then
                |              density.Value = 1
                |          End If

        :rtype: str
        """

        return self.enum_param.ValueEnum

    @value_enum.setter
    def value_enum(self, value: str):
        """
        :param str value:
        """

        self.enum_param.ValueEnum = value

    def __repr__(self):
        return f'EnumParam(name="{ self.name }")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.drafting_interfaces.drawing_arrows import DrawingArrows
from pycatia.drafting_interfaces.drawing_components import DrawingComponents
from pycatia.drafting_interfaces.drawing_dimensions import DrawingDimensions
from pycatia.drafting_interfaces.drawing_pictures import DrawingPictures
from pycatia.drafting_interfaces.drawing_tables import DrawingTables
from pycatia.drafting_interfaces.drawing_texts import DrawingTexts
from pycatia.drafting_interfaces.drawing_threads import DrawingThreads
from pycatia.drafting_interfaces.drawing_weldings import DrawingWeldings
from pycatia.mec_mod_interfaces.geometric_elements import GeometricElements
from pycatia.sketcher_interfaces.factory_2D import Factory2D
from pycatia.system_interfaces.any_object import AnyObject


class Layout2DView(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     Layout2DView
                | 
                | The interface to access a Layout2D View.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.layout_2d_view = com_object

    @property
    def angle(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Angle() As double
                | 
                |     Returns or sets the angle of the Layout2D view. The angle is measured
                |     between the axis system of the Layout2D view and the axis system of the
                |     Layout2D sheet where the Layout2D view lies. The angle is measured in radians
                |     and is counted counterclockwise.
                | 
                |     Example:
                |         This example sets the angle of the MyView Layout2D view to 90 degrees
                |         clockwise. You first need to compute the angle in radians and set the minus
                |         sign to indicate the rotation is clockwise.
                | 
                |          PI = 3.1415926535
                |          Angle90Clockwise = -PI/2
                |          MyView.Angle = Angle90Clockwise

        :rtype: float
        """

        return self.layout_2d_view.Angle

    @angle.setter
    def angle(self, value: float):
        """
        :param float value:
        """

        self.layout_2d_view.Angle = value

    @property
    def arrows(self) -> DrawingArrows:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Arrows() As DrawingArrows (Read Only)
                | 
                |     Returns the drawing arrow collection of the Layout2D view.
                | 
                |     Example:
                |         This example retrieves in ArrowCollection the collection of arrows of
                |         the MyView Layout2D view.
                | 
                |          Dim ArrowCollection As DrawingArrows
                |          Set ArrowCollection = MyView.Arrows

        :rtype: DrawingArrows
        """

        return DrawingArrows(self.layout_2d_view.Arrows)

    @property
    def components(self) -> DrawingComponents:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Components() As DrawingComponents (Read Only)
                | 
                |     Returns the Layout2D component instances collection (i.e. ditto collection)
                |     of the Layout2D view.
                | 
                |     Example:
                |         This example retrieves in ComponentCollection the collection of
                |         component instances of the MyView Layout2D view.
                | 
                |          Dim ComponentCollection As DrawingComponents
                |          Set ComponentCollection = MyView.Components

        :rtype: DrawingComponents
        """

        return DrawingComponents(self.layout_2d_view.Components)

    @property
    def dimensions(self) -> DrawingDimensions:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Dimensions() As DrawingDimensions (Read Only)
                | 
                |     Returns the drawing dimension collection of the Layout2D
                |     view.
                | 
                |     Example:
                |         This example retrieves in DimensionCollection the collection of
                |         dimensions of the MyView Layout2D view.
                | 
                |          Dim DimensionCollection As DrawingDimensions
                |          Set DimensionCollection = MyView.Dimensions

        :rtype: DrawingDimensions
        """

        return DrawingDimensions(self.layout_2d_view.Dimensions)

    @property
    def factory_2d(self) -> Factory2D:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Factory2D() As Factory2D (Read Only)
                | 
                |     Returns the 2D factory of the Layout2D view. Take care that you must open
                |     edition on a sketch before adding or modifying elements in it. Take care that
                |     you must close edition on a sketch to keep all modifications before saving
                |     document. To get Sketch from factory2D:
                | 
                |       Set mySketch = my2DFactory.GetParent
                |      
                | 
                |     Example:
                |         The following example returns in my2DFactory the 2D
                |         factory
                |         of the view myView:
                | 
                |          Set my2DFactory = myView.Factory2D

        :rtype: Factory2D
        """

        return Factory2D(self.layout_2d_view.Factory2D)

    @property
    def frame_visualization(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property FrameVisualization() As boolean
                | 
                |     Returns or sets the Layout2D view frame visualization
                |     state.
                |     True if the Layout2D view frame is visible.
                | 
                |     Example:
                |         This example shows the frame of the MyView Layout2D
                |         view.
                | 
                |          MyView.FrameVisualization = True

        :rtype: bool
        """

        return self.layout_2d_view.FrameVisualization

    @frame_visualization.setter
    def frame_visualization(self, value: bool):
        """
        :param bool value:
        """

        self.layout_2d_view.FrameVisualization = value

    @property
    def geometric_elements(self) -> GeometricElements:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property GeometricElements() As GeometricElements (Read
                | Only)
                | 
                |     Returns the collection of geometric elements included in the Layout2D view
                |     sketch.
                | 
                |     Example:
                |         The following example returns in colGeometry the list of geometric
                |         elements in the view myView:
                | 
                |          Dim colGeometry As GeometricElements
                |          Set colGeometry = MyView.GeometricElements

        :rtype: GeometricElements
        """

        return GeometricElements(self.layout_2d_view.GeometricElements)

    @property
    def lock_status(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property LockStatus() As boolean
                | 
                |     Returns or sets the lock status of a Layout2D view.
                |     precondition: This property does not exist for the detail view. In this
                |     case, the method returns failed.
                | 
                |     Example:
                |         This example locks the ViewToWorkOn Layout2D view.
                | 
                |          ViewToWorkOn.LockStatus = True

        :rtype: bool
        """

        return self.layout_2d_view.LockStatus

    @lock_status.setter
    def lock_status(self, value: bool):
        """
        :param bool value:
        """

        self.layout_2d_view.LockStatus = value

    @property
    def pictures(self) -> DrawingPictures:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Pictures() As DrawingPictures (Read Only)
                | 
                |     Returns the drawing picture collection of the Layout2D
                |     view.
                | 
                |     Example:
                |         This example retrieves in PictureCollection the collection of pictures
                |         of the MyView Layout2D view.
                | 
                |          Dim PictureCollection As DrawingPictures
                |          Set PictureCollection = MyView.Pictures

        :rtype: DrawingPictures
        """

        return DrawingPictures(self.layout_2d_view.Pictures)

    @property
    def reference_view(self) -> 'Layout2DView':
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ReferenceView() As Layout2DView
                | 
                |     Returns or sets the reference view. The reference view is also the parent
                |     view to which the current Layout2D view is linked and which is used as
                |     reference for alignment. Generally, the reference view is the front view, and
                |     the other views, such as the top, bottom, left, and right views, are linked to
                |     it. This reference Layout2D view is used:
                | 
                |         When moving the current Layout2D view. Its location remains constrained
                |         to the reference view, depending on its type. For example, a left view can move
                |         horizontally and a top view can move vertically.
                |         To update the scale of the current Layout2D view according to the
                |         modification performed to the one of the reference Layout2D
                |         view.
                | 
                |     Example:
                |         This example retrieves in ReferenceView the view used as reference by
                |         the MyView Layout2D view.
                | 
                |          Dim ReferenceView As Layout2DView
                |          Set ReferenceView = MyView.RefView

        :rtype: Layout2DView
        """

        return Layout2DView(self.layout_2d_view.ReferenceView)

    @reference_view.setter
    def reference_view(self, value: 'Layout2DView'):
        """
        :param Layout2DView value:
        """

        self.layout_2d_view.ReferenceView = value

    @property
    def tables(self) -> DrawingTables:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Tables() As DrawingTables (Read Only)
                | 
                |     Returns the drawing table collection of the drawing view.
                | 
                |     Example:
                |         This example retrieves in TextCollection the collection of texts of the
                |         MyView Layout2D view.
                | 
                |          Dim TableCollection As DrawingTables
                |          Set TableCollection = MyView.Tables

        :rtype: DrawingTables
        """

        return DrawingTables(self.layout_2d_view.Tables)

    @property
    def texts(self) -> DrawingTexts:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Texts() As DrawingTexts (Read Only)
                | 
                |     Returns the drawing text collection of the Layout2D view.
                | 
                |     Example:
                |         This example retrieves in TextCollection the collection of texts of the
                |         MyView Layout2D view.
                | 
                |          Dim TextCollection As DrawingTexts
                |          Set TextCollection = MyView.Texts

        :rtype: DrawingTexts
        """

        return DrawingTexts(self.layout_2d_view.Texts)

    @property
    def threads(self) -> DrawingThreads:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Threads() As DrawingThreads (Read Only)
                | 
                |     Returns the drawing thread collection of the Layout2D
                |     view.
                | 
                |     Example:
                |         This example retrieves in ThreadCollection the collection of threads of
                |         the MyView Layout2D view.
                | 
                |          Dim ThreadCollection As DrawingThreads
                |          Set ThreadCollection = MyView.Threads

        :rtype: DrawingThreads
        """

        return DrawingThreads(self.layout_2d_view.Threads)

    @property
    def view_scale(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ViewScale() As double
                | 
                |     Returns or sets the scale of the Layout2D view.
                | 
                |     Example:
                |         This example sets the scale of the MyView Layout2D view to
                |         0.5.
                | 
                |          MyView.Scale = 0.5

        :rtype: float
        """

        return self.layout_2d_view.ViewScale

    @view_scale.setter
    def view_scale(self, value: float):
        """
        :param float value:
        """

        self.layout_2d_view.ViewScale = value

    @property
    def visu_2d_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Visu2DMode() As CatView2DModeVisu
                | 
                |     Sets/Gets the 2D mode for background visualization of the
                |     view.
                | 
                |     See also:
                |         CatView2DModeVisu 
                |     Example:
                |
                |              This example shows how to switch on the background 2D
                |              mode
                |
                |              View1.Visu2DMode = catView2DModeNoShow

        :return: enum cat_view_2d_mode_visu
        :rtype: int
        """

        return self.layout_2d_view.Visu2DMode

    @visu_2d_mode.setter
    def visu_2d_mode(self, value: int):
        """
        :param int value: enum cat_view_2d_mode_visu
        """

        self.layout_2d_view.Visu2DMode = value

    @property
    def visu_background(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property VisuBackground() As CatVisuBackgroundMode
                | 
                |     Sets/Gets the 2D-3D background visu mode of the view ie in the 3D windows
                |     and in the background of each view in every 2D context.
                | 
                |     See also:
                |         CatVisuBackgroundMode 
                |     Example:
                | 
                |           
                | 
                |              This example shows how to set the background to
                |              LowInt
                |              
                | 
                |              View1.VisuBackground = catLowIntPick

        :return: enum cat_visu_background_mode
        :rtype: int
        """

        return self.layout_2d_view.VisuBackground

    @visu_background.setter
    def visu_background(self, value: int):
        """
        :param int value: enum cat_visu_background_mode
        """

        self.layout_2d_view.VisuBackground = value

    @property
    def visu_in_3d(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property VisuIn3D() As CatVisuIn3DMode
                | 
                |     Sets/Gets the 3D visualization mode of the view in the 3D Viewer ie in the
                |     3D windows and in the background of each view in every 2D
                |     context.
                | 
                |     See also:
                |         CatVisuIn3DMode 
                |     Example:
                | 
                |              This example shows how to make the View1 Layout2D view visible in
                |              3D
                |
                |              View1.HideIn3DSize = catShowAll

        :return: enum cat_visu_in_3d_mode
        :rtype: int
        """

        return self.layout_2d_view.VisuIn3D

    @visu_in_3d.setter
    def visu_in_3d(self, value: int):
        """
        :param int value: enum cat_visu_in_3d_mode
        """

        self.layout_2d_view.VisuIn3D = value

    @property
    def weldings(self) -> DrawingWeldings:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Weldings() As DrawingWeldings (Read Only)
                | 
                |     Returns the drawing welding collection of the Layout2D
                |     view.
                | 
                |     Example:
                |         This example retrieves in weldingCollection the collection of weldings
                |         of the MyView Layout2D view.
                | 
                |          Dim weldingCollection As DrawingWeldings
                |          Set weldingCollection = MyView.Weldings

        :rtype: DrawingWeldings
        """

        return DrawingWeldings(self.layout_2d_view.Weldings)

    @property
    def x(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property x() As double
                | 
                |     Returns or sets the x coordinate of the Layout2D view coordinate system
                |     origin. It is expressed with respect to the sheet coordinate system. This
                |     coordinate, like any length, is measured in millimeters.
                | 
                |     Example:
                |         This example retrieves the x coordinate of the coordinate system origin
                |         of the MyView.
                | 
                |          X = MyView.x

        :rtype: float
        """

        return self.layout_2d_view.x

    @x.setter
    def x(self, value: float):
        """
        :param float value:
        """

        self.layout_2d_view.x = value

    @property
    def y(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property y() As double
                | 
                |     Returns or sets the y coordinate of the Layout2D view coordinate system
                |     origin. It is expressed with respect to the sheet coordinate system. This
                |     coordinate, like any length, is measured in millimeters.
                | 
                |     Example:
                |         This example sets the y coordinate of the coordinate system origin of
                |         the MyView to 5 inches. You need first to convert the 5 inches into
                |         millimeters.
                | 
                |          NewYCoordinate = 5*25.4
                |          MyView.y = NewYCoordinate

        :rtype: float
        """

        return self.layout_2d_view.y

    @y.setter
    def y(self, value: float):
        """
        :param float value:
        """

        self.layout_2d_view.y = value

    def activate(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Activate()
                | 
                |     Activates the Layout2D view. Activating a Layout2D view means that this
                |     Layout2D view is the one on which the end-user is now
                |     working.
                | 
                |     Example:
                |         This example activates the ViewToWorkOn Layout2D view.
                | 
                |          ViewToWorkOn.Activate()

        :rtype: None
        """
        return self.layout_2d_view.Activate()

    def aligned_with_reference_view(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AlignedWithReferenceView()
                | 
                |     Activates the alignment with the reference view. Activating the alignment
                |     with the reference view restores the constraints that the reference view
                |     imposes to the current Layout2D view.
                | 
                |     Example:
                |         This example activates the alignment from the MyView Layout2D view to
                |         its reference view.
                | 
                |          MyView.AlignedWithReferenceView()

        :rtype: None
        """
        return self.layout_2d_view.AlignedWithReferenceView()

    def get_view_name(self, i_view_name_prefix: str, i_view_name_ident: str, i_view_name_suffix: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetViewName(CATBSTR iViewNamePrefix,
                | CATBSTR iViewNameIdent,
                | CATBSTR iViewNameSuffix)
                | 
                |     Returns the prefix, the ident and the suffix of the name of the Layout2D
                |     view. The method returns an error in case of 2D component reference. Do not
                |     confuse with the method Name which can be different.
                | 
                |     Example:
                | 
                |           This example gets the prefix, the ident, and the suffix of the name
                |           
                |          of the MyView Layout2D view
                |          
                | 
                |          Dim MyPrefix, MyIdent, MySuffix As CATBSTR
                |          MyView.GetViewName (MyPrefix, MyIdent, MySuffix)

        :param str i_view_name_prefix:
        :param str i_view_name_ident:
        :param str i_view_name_suffix:
        :rtype: None
        """
        return self.layout_2d_view.GetViewName(i_view_name_prefix, i_view_name_ident, i_view_name_suffix)

    def save_edition(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SaveEdition()
                | 
                |     Saves the Sketch Edition. Once you have finished working with the Layout2D
                |     view, you must save its edition in order to register modification for
                |     UNDO/REDO. Indeed when activating a view, this view is open in edition while
                |     the previous active view is closed in edition. So calling SaveEdition() before
                |     exiting a macro without changing active view will allow a correct UNDO/REDO
                |     behavior.
                | 
                |     Example:
                |         The following example saves the edition of the Layout2D view
                |         MyView:
                | 
                |          MyView.SaveEdition

        :rtype: None
        """
        return self.layout_2d_view.SaveEdition()

    def set_view_name(self, i_view_name_prefix: str, i_view_name_ident: str, i_view_name_suffix: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetViewName(CATBSTR iViewNamePrefix,
                | CATBSTR iViewNameIdent,
                | CATBSTR iViewNameSuffix)
                | 
                |     Sets the prefix, the ident and the suffix of the name of the Layout2D view.
                |     The method returns an error in case of 2D component reference. Do not confuse
                |     with the method Name which can be different.
                | 
                |     Example:
                | 
                |           This example sets the prefix, the ident, and the suffix of the name
                |           
                |          of the MyView Layout2D view respectively to "MyPrefix",
                |          "MyIdent",
                |          and "MySuffix".
                |          
                | 
                |          MyView.SetViewName ("MyPrefix", "MyIdent",
                |          "MySuffix")

        :param str i_view_name_prefix:
        :param str i_view_name_ident:
        :param str i_view_name_suffix:
        :rtype: None
        """
        return self.layout_2d_view.SetViewName(i_view_name_prefix, i_view_name_ident, i_view_name_suffix)

    def size(self, o_values: tuple) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Size(CATSafeArrayVariant oValues)
                | 
                |     Returns the bounding box of the Layout2D view.
                |     Warning: This method is not implemented.
                | 
                |     Parameters:
                | 
                |         oValues
                |             The values of the view bounding box: Xmin, Xmax, Ymin, Ymax
                |             
                | 
                |     Example:
                | 
                |           
                | 
                |              This example gets the bounding box of the ViewToWorkOn Layout2D
                |              view.
                |              
                | 
                |              Dim oXY(4) As Double
                |              ViewToWorkOn.Size oXY
                |              Xmin = oXY(0)
                |              Xmax = oXY(1)
                |              Ymin = oXY(2)
                |              Ymax = oXY(3)

        :param tuple o_values:
        :rtype: Double
        """
        return self.layout_2d_view.Size(o_values)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'size'
        # # vba_code = """
        # # Public Function size(layout2_d_view)
        # #     Dim oValues (2)
        # #     layout2_d_view.Size oValues
        # #     size = oValues
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def un_aligned_with_reference_view(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub UnAlignedWithReferenceView()
                | 
                |     Deactivates the alignment with the reference view. Deactivating the
                |     alignment to the reference view removes the constraints that the reference view
                |     imposes to the current Layout2D view. You can then, for example, move and
                |     position it freely.
                | 
                |     Example:
                |         This example deactivates the alignment from the MyView Layout2D view to
                |         its reference view.
                | 
                |          MyView.UnAlignedWithReferenceView()

        :rtype: None
        """
        return self.layout_2d_view.UnAlignedWithReferenceView()

    def __repr__(self):
        return f'Layout2DView(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dnb_human_modeling_interfaces.swk_segment import SWKSegment
from pycatia.system_interfaces.any_object import AnyObject


class SWKSegmentNode(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SWKSegmentNode
                | 
                | This interface characterizes a segment node.
                | 
                | A segment node is a convenient way to regroup segments. The segment nodes are
                | the entities that appear under the manikin in the specification tree, and that
                | regroup segments together (i.e. "Trunk", "Cervical", "Right
                | Fingers").
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.swk_segment_node = com_object

    @property
    def nb_children_nodes(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property NbChildrenNodes() As long (Read Only)
                | 
                |     Returns the number of children segment nodes under this node.

        :rtype: int
        """

        return self.swk_segment_node.NbChildrenNodes

    @property
    def nb_children_segments(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property NbChildrenSegments() As long (Read Only)
                | 
                |     Returns the number of children segments under this node.

        :rtype: int
        """

        return self.swk_segment_node.NbChildrenSegments

    def get_segment(self, pi_index: int) -> SWKSegment:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetSegment(long piIndex) As SWKSegment
                | 
                |     Returns a specific child of the segment node, based on an
                |     index.
                | 
                |     Parameters:
                | 
                |         piIndex
                |             The index of the segment to retrieve.
                |             The first segment is at index 0.
                |             The value of this parameter should not be higher than the number of
                |             segments on this segment node, minus 1.

        :param int pi_index:
        :rtype: SWKSegment
        """
        return SWKSegment(self.swk_segment_node.GetSegment(pi_index))

    def get_segment_node(self, pi_index: int) -> 'SWKSegmentNode':
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetSegmentNode(long piIndex) As SWKSegmentNode
                | 
                |     Returns a specific child of the segment node, based on an
                |     index.
                | 
                |     Parameters:
                | 
                |         piIndex
                |             The index of the segment node to retrieve.
                |             The first segment is at index 0.
                |             The value of this parameter should not be higher than the number of
                |             children nodes on this segment node, minus 1.

        :param int pi_index:
        :rtype: SWKSegmentNode
        """
        return SWKSegmentNode(self.swk_segment_node.GetSegmentNode(pi_index))

    def mirror_copy_posture(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub MirrorCopyPosture()
                | 
                |     Copy the posture on the equivalent segment node, on the other side of the
                |     manikin. For instance, it copies the posture from the right leg to the left
                |     leg.

        :rtype: None
        """
        return self.swk_segment_node.MirrorCopyPosture()

    def reset_posture(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ResetPosture()
                | 
                |     Set the posture of all segment under this node back to their default
                |     position.

        :rtype: None
        """
        return self.swk_segment_node.ResetPosture()

    def swap_posture(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SwapPosture()
                | 
                |     Swap the posture with the equivalent segment node, on the other side of the
                |     manikin. For instance, the right leg takes the posture of the left leg, and
                |     vice versa.

        :rtype: None
        """
        return self.swk_segment_node.SwapPosture()

    def __repr__(self):
        return f'SWKSegmentNode(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from typing import TYPE_CHECKING

from pycatia.system_interfaces.any_object import AnyObject

if TYPE_CHECKING:
    from pycatia.in_interfaces.folder import Folder

class FileComponent(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     FileComponent
                | 
                | Represents the file object.
                | Role: The file object allows to manipulate files with UNIX and Windows. Use it
                | instead of the one of Visual Basic to make portable macros. Its gives access to
                | information about the file and can open a file as a TextStream
                | object.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.file_component = com_object

    @property
    def parent_folder(self) -> 'Folder':
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property ParentFolder() As Folder
                | 
                |     Returns or sets the parent folder of the file.
                | 
                |     Example:
                |         This example sets the folder ParentFold as parent of the file TestFile.
                |         This moves the file into ParentFold.
                | 
                |          TestFile.ParentFolder

        :rtype: Folder
        """
        from pycatia.in_interfaces.folder import Folder
        return Folder(self.file_component.ParentFolder)

    @parent_folder.setter
    def parent_folder(self, value: 'Folder'):
        """
        :param Folder value:
        """

        self.file_component.ParentFolder = value

    @property
    def path(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Path() As CATBSTR (Read Only)
                | 
                |     Returns the full path of the file.
                | 
                |     Example:
                |         This example retrieves in FilePath the path of the File
                |         TestFile.
                | 
                |          Dim FilePath As String
                |          FilePath = TestFile.Path

        :rtype: str
        """

        return self.file_component.Path

    def __repr__(self):
        return f'FileComponent(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.manufacturing_interfaces.manufacturing_activities import ManufacturingActivities
from pycatia.manufacturing_interfaces.manufacturing_activity import ManufacturingActivity
from pycatia.manufacturing_interfaces.manufacturing_machine import ManufacturingMachine
from pycatia.manufacturing_interfaces.manufacturing_machining_axis import ManufacturingMachiningAxis
from pycatia.manufacturing_interfaces.manufacturing_view import ManufacturingView
from pycatia.product_structure_interfaces.product import Product
from pycatia.system_interfaces.any_object import AnyObject
from pycatia.types.general import cat_variant


class ManufacturingSetup(ManufacturingActivity):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     DMAPSInterfaces.Activity
                |                        ManufacturingInterfaces.ManufacturingActivity
                |                             ManufacturingSetup
                | 
                | A ManufacturingSetup for a Manufacturing Document.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.manufacturing_setup = com_object

    @property
    def comment(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Comment() As CATBSTR
                | 
                |     Return the Default Comment of a Manufacturing Setup.
                | 
                |     Example:
                |         The following example return the comment SetupComment of to the
                |         manufacturing setup CurrentSetup
                | 
                |          Set CurrentSetup.Comment

        :rtype: str
        """

        return self.manufacturing_setup.Comment

    @comment.setter
    def comment(self, value: str):
        """
        :param str value:
        """

        self.manufacturing_setup.Comment = value

    @property
    def machine(self) -> ManufacturingMachine:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Machine() As ManufacturingMachine
                | 
                |     Give the Machine linked to a Manufacturing Setup.
                | 
                |     Example:
                |         The following example returns the Machine linked to the manufacturing
                |         setup CurrentSetup
                | 
                |          Set Machine = CurrentSetup.Machine

        :rtype: ManufacturingMachine
        """

        return ManufacturingMachine(self.manufacturing_setup.Machine)

    @machine.setter
    def machine(self, value: ManufacturingMachine):
        """
        :param ManufacturingMachine value:
        """

        self.manufacturing_setup.Machine = value

    @property
    def machining_axis_system(self) -> ManufacturingMachiningAxis:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property MachiningAxisSystem() As
                | ManufacturingMachiningAxis
                | 
                |     Retrieves the Machining Axis system from a Manufacturing
                |     Setup.
                | 
                |     Example:
                |         The following example retrieves the Machining Axis system
                |         oMachiningAxis from the manufacturing setup
                |         CurrentSetup
                | 
                |          Set oMachiningAxis = CurrentSetup.MachiningAxisSystem

        :rtype: ManufacturingMachiningAxis
        """

        return ManufacturingMachiningAxis(self.manufacturing_setup.MachiningAxisSystem)

    @machining_axis_system.setter
    def machining_axis_system(self, value: ManufacturingMachiningAxis):
        """
        :param ManufacturingMachiningAxis value:
        """

        self.manufacturing_setup.MachiningAxisSystem = value

    @property
    def product(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Product(Product iProduct)
                | 
                |     Associate the Product to a Manufacturing Setup.
                | 
                |     Example:
                |         The following example associates the Product iProduct to the
                |         manufacturing setup CurrentSetup
                | 
                |          CurrentSetup.Product = iProduct

        :rtype: None
        """

        return self.manufacturing_setup.Product

    @product.setter
    def product(self, value: Product):
        """
        :param False value:
        """

        self.manufacturing_setup.Product = value.com_object

    @property
    def programs(self) -> ManufacturingActivities:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Programs() As MfgActivities (Read Only)
                | 
                |     Give the List of Programs linked to a Manufacturing Setup.
                | 
                |     Example:
                |         The following example returns the list of Programs ProgramsList linked
                |         to the manufacturing Setup CurrentSetup
                | 
                |          Set ProgramsList = CurrentSetup.Programs

        :rtype: ManufacturingActivities
        """

        return ManufacturingActivities(self.manufacturing_setup.Programs)

    def create_machine(self, i_type_machine: str) -> ManufacturingMachine:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func CreateMachine(CATBSTR iTypeMachine) As
                | ManufacturingMachine
                | 
                |     Initialise the Manufacturing Machine linked to a Manufacturing
                |     Setup.
                | 
                |     Example:
                |         The following example initialise the machine
                |         Mfg3AxisWithTableRotationMachine as Manufacturing Machine in the manufacturing
                |         setup CurrentSetup
                | 
                |          call CurrentSetup.CreateMachine(Mfg3AxisWithTableRotationMachine)

        :param str i_type_machine:
        :rtype: ManufacturingMachine
        """
        return ManufacturingMachine(self.manufacturing_setup.CreateMachine(i_type_machine))

    def design_geometries_count(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func DesignGeometriesCount() As long
                | 
                |     Returns the number of design geometries from a Manufacturing
                |     Setup.
                | 
                |     Parameters:
                | 
                |         oDesignGeometriesListSize
                |             The number of design geometries of this setup 
                | 
                |     Example:
                |         The following example retrieves the number of design geometries of the
                |         setup CurrentSetup in DesignGeometriesListSize.
                | 
                |          Dim CurrentSetup As ManufacturingSetup
                |          Set CurrentSetup = ...
                |          Dim DesignGeometriesListSize As Long
                |          DesignGeometriesListSize = CurrentSetup.DesignGeometriesCount

        :rtype: int
        """
        return self.manufacturing_setup.DesignGeometriesCount()

    def export_cat_setting(self, dir_path: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ExportCATSetting(CATBSTR dirPath)
                | 
                |     ExportCATSetting. Export All Machining CATSetting file to a location in xml format.
                |     dirPath = Absolute path to the location where all settings should be exported.
                |     eg, "D:/dir/" Call on Current Manufacturngsetup

        :param str dir_path:
        :rtype: None
        """
        return self.manufacturing_setup.ExportCATSetting(dir_path)

    def fixture_geometries_count(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func FixtureGeometriesCount() As long
                | 
                |     Returns the number of fixture geometries from a Manufacturing
                |     Setup.
                | 
                |     Parameters:
                | 
                |         oFixtureGeometriesListSize
                |             The number of fixture geometries of this setup 
                | 
                |     Example:
                |         The following example retrieves the number of fixture geometries of the
                |         setup CurrentSetup in FixtureGeometriesListSize.
                | 
                |          Dim CurrentSetup As ManufacturingSetup
                |          Set CurrentSetup = ...
                |          Dim FixtureGeometriesListSize As Long
                |          FixtureGeometriesListSize = CurrentSetup.FixtureGeometriesCount

        :rtype: int
        """
        return self.manufacturing_setup.FixtureGeometriesCount()

    def get_machining_axis_system_name(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetMachiningAxisSystemName() As CATBSTR
                | 
                |     Retrieves the Name of the Machining Axis system from a Manufacturing
                |     Setup.
                | 
                |     Example:
                |         The following example retrieves the Name of the Machining Axis
                |         systemoMachiningAxisSystemName from the manufacturing setup
                |         CurrentSetup
                | 
                |          Set oMachiningAxisSystemName = CurrentSetup.GetMachiningAxisSystemName

        :rtype: str
        """
        return self.manufacturing_setup.GetMachiningAxisSystemName()

    def get_manufacturing_view(self) -> ManufacturingView:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetManufacturingView() As ManufacturingView
                | 
                |     Retrieves the Manufacturing View from a Manufacturing
                |     Setup.
                | 
                |     Example:
                |         The following example retrievec the Manufacturing View MfgView from the
                |         manufacturing setup CurrentSetup
                | 
                |          Set MfgView = CurrentSetup.GetManufacturingView

        :rtype: ManufacturingView
        """
        return ManufacturingView(self.manufacturing_setup.GetManufacturingView())

    def get_part_name(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetPartName() As CATBSTR
                | 
                |     Retrieves the Name of the Design Part from a Manufacturing
                |     Setup.
                | 
                |     Example:
                |         The following example retrieves the Name of the Design PartoPartName
                |         from the manufacturing setup CurrentSetup
                | 
                |          Set oPartName = CurrentSetup.GetPartName

        :rtype: str
        """
        return self.manufacturing_setup.GetPartName()

    def get_product_instance(self) -> Product:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetProductInstance() As Product
                | 
                |     Give the Product of the ProductList linked to a Manufacturing
                |     Setup.
                | 
                |     Example:
                |         The following example returns the Product linked to the manufacturing
                |         setup CurrentSetup
                | 
                |          Set Product = CurrentSetup.GetProductInstance

        :rtype: Product
        """
        return Product(self.manufacturing_setup.GetProductInstance())

    def get_safety_plane(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetSafetyPlane() As CATSafeArrayVariant
                | 
                |     Retrieves the Safety Plane from a Manufacturing Setup.
                | 
                |     Example:
                |         The following example retrieves the Safety Plane oMathPLane from the
                |         manufacturing setup CurrentSetup The size of oMathPlane is 9 (origin, first
                |         direction, second direction)
                | 
                |          Set oMathPlane= CurrentSetup.GetSafetyPlane

        :rtype: tuple
        """
        return self.manufacturing_setup.GetSafetyPlane()

    def get_stock_from_setup(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetStockFromSetup(CATBSTR oStockPath)
                | 
                |     Retrieves the path of the Stock file from a Manufacturing
                |     Setup.
                | 
                |     Example:
                |         The following example retrieves the the path of the Stock
                |         fileoStockPath from the manufacturing setup
                |         CurrentSetup
                | 
                |          call CurrentSetup.GetStockFromSetup(oStockPath)

        :rtype: str
        """
        return self.manufacturing_setup.GetStockFromSetup()

    def get_tool_change_point(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetToolChangePoint(double oX,
                | double oY,
                | double oZ)
                | 
                |     Get the ToolChange point of the machine linked to a Manufacturing
                |     Setup.
                | 
                |     Example:
                |         The following example gets the point with coordinates X,Y,Z as
                |         ToolChangePoint in the manufacturing setup
                |         CurrentSetup
                | 
                |          call CurrentSetup.GetToolChangePoint(X,Y,Z)

        :rtype: tuple
        """
        return self.manufacturing_setup.GetToolChangePoint()

    def import_cat_setting(self, xml_file_path: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ImportCATSetting(CATBSTR XMLFilePath)
                | 
                |     ImportCATSetting. Import the CATSetting in xml format from a specified location.
                |     XMLFilePath = Path to the xml file.
                |     eg, "D:/dirs/settings.xml" Call on Current Manufacturngsetup

        :param str xml_file_path:
        :rtype: None
        """
        return self.manufacturing_setup.ImportCATSetting(xml_file_path)

    def in_process_model_bodies_count(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func InProcessModelBodiesCount() As long
                | 
                |     Returns the number of In Process Model Bodies from a Manufacturing
                |     Setup.
                | 
                |     Parameters:
                | 
                |         oIPMBodiesListSize
                |             The number of In Process Model Bodies of this setup
                |             
                | 
                |     Example:
                |         The following example retrieves the number of In Process Model Bodies
                |         of the setup CurrentSetup in IPMBodiesListSize.
                | 
                |          Dim CurrentSetup As ManufacturingSetup
                |          Set CurrentSetup = ...
                |          Dim IPMBodiesListSize As Long
                |          IPMBodiesListSize = CurrentSetup.InProcessModelBodiesCount

        :rtype: int
        """
        return self.manufacturing_setup.InProcessModelBodiesCount()

    def list_design_geometries(self, o_list_of_design_geometries: tuple) -> cat_variant:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ListDesignGeometries(CATSafeArrayVariant
                | oListOfDesignGeometries)
                | 
                |     Retrieves the design geometries list from a Manufacturing Setup. Each of
                |     these geometries may be either a Product or a Body.
                | 
                |     Parameters:
                | 
                |         oListOfDesignGeometries
                |             The retrieved list.
                |             The array must be previously initialized using the
                |             
                | 
                |         DesignGeometriesCount method. 
                | 
                | Example:
                |     The following example retrieves the design geometries list of the
                |     manufacturing setup CurrentSetup in
                |     ListOfDesignGeometries.
                | 
                |      Dim CurrentSetup As ManufacturingSetup
                |      Set CurrentSetup = ...
                |      Dim DesignGeometriesListSize As Long
                |      DesignGeometriesListSize = CurrentSetup.DesignGeometriesCount
                |      If DesignGeometriesListSize > 0 Then
                |        Dim ListOfDesignGeometries() As Variant
                |        Redim
                |        ListOfDesignGeometries(DesignGeometriesListSize-1)
                |       CurrentSetup.ListDesignGeometries(ListOfDesignGeometries)
                |      End If

        :param tuple o_list_of_design_geometries:
        :rtype: cat_variant
        """
        return self.manufacturing_setup.ListDesignGeometries(o_list_of_design_geometries)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'list_design_geometries'
        # # vba_code = """
        # # Public Function list_design_geometries(manufacturing_setup)
        # #     Dim oListOfDesignGeometries (2)
        # #     manufacturing_setup.ListDesignGeometries oListOfDesignGeometries
        # #     list_design_geometries = oListOfDesignGeometries
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def list_design_geometries_products(self, o_list_of_design_geometries_products: tuple) -> cat_variant:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ListDesignGeometriesProducts(CATSafeArrayVariant
                | oListOfDesignGeometriesProducts)
                | 
                |     Retrieves the design geometries products list from a Manufacturing Setup.
                |     Each of these geometries may be either a Product or a
                |     Body.
                | 
                |     Parameters:
                | 
                |         oListOfDesignGeometriesProducts
                |             The retrieved list.
                |             The array must be previously initialized using the
                |             
                |         DesignGeometriesCount method.
                | 
                | Example:
                |     The following example retrieves the design geometries list of the
                |     manufacturing setup CurrentSetup in
                |     ListOfDesignGeometriesProducts.
                | 
                |      Dim CurrentSetup As ManufacturingSetup
                |      Set CurrentSetup = ...
                |      Dim DesignGeometriesListSize As Long
                |      DesignGeometriesListSize = CurrentSetup.DesignGeometriesCount
                |      If DesignGeometriesListSize > 0 Then
                |        Dim ListOfDesignGeometries() As Variant
                |        Redim
                |        ListOfDesignGeometries(DesignGeometriesListSize-1)
                |       CurrentSetup.ListDesignGeometriesProducts(ListOfDesignGeometriesProducts)
                |      End If

        :param tuple o_list_of_design_geometries_products:
        :rtype: cat_variant
        """
        return self.manufacturing_setup.ListDesignGeometriesProducts(o_list_of_design_geometries_products)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'list_design_geometries_products'
        # # vba_code = """
        # # Public Function list_design_geometries_products(manufacturing_setup)
        # #     Dim oListOfDesignGeometriesProducts (2)
        # #     manufacturing_setup.ListDesignGeometriesProducts oListOfDesignGeometriesProducts
        # #     list_design_geometries_products = oListOfDesignGeometriesProducts
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def list_fixture_geometries(self, o_list_of_fixture_geometries: tuple) -> cat_variant:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ListFixtureGeometries(CATSafeArrayVariant
                | oListOfFixtureGeometries)
                | 
                |     Retrieves the fixture geometries list from a Manufacturing Setup. Each of
                |     these geometries may be either a Product or a Body.
                | 
                |     Parameters:
                | 
                |         oListOfFixtureGeometries
                |             The retrieved list.
                |             The array must be previously initialized using the
                |             
                | 
                |         FixtureGeometriesCount method. 
                | 
                | Example:
                |     The following example retrieves the fixture geometries list of the
                |     manufacturing setup CurrentSetup in
                |     ListOfFixtureGeometries.
                | 
                |      Dim CurrentSetup As ManufacturingSetup
                |      Set CurrentSetup = ...
                |      Dim FixtureGeometriesListSize As Long
                |      FixtureGeometriesListSize = CurrentSetup.FixtureGeometriesCount
                |      If FixtureGeometriesListSize > 0 Then
                |        Dim ListOfFixtureGeometries() As Variant
                |        Redim
                |        ListOfFixtureGeometries(FixtureGeometriesListSize-1)
                |       CurrentSetup.ListFixtureGeometries(ListOfFixtureGeometries)
                |      End If

        :param tuple o_list_of_fixture_geometries:
        :rtype: cat_variant
        """
        return self.manufacturing_setup.ListFixtureGeometries(o_list_of_fixture_geometries)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'list_fixture_geometries'
        # # vba_code = """
        # # Public Function list_fixture_geometries(manufacturing_setup)
        # #     Dim oListOfFixtureGeometries (2)
        # #     manufacturing_setup.ListFixtureGeometries oListOfFixtureGeometries
        # #     list_fixture_geometries = oListOfFixtureGeometries
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def list_fixture_geometries_products(self, o_list_of_fixture_geometries_products: tuple) -> cat_variant:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ListFixtureGeometriesProducts(CATSafeArrayVariant
                | oListOfFixtureGeometriesProducts)
                | 
                |     Retrieves the Fixture geometries products list from a Manufacturing Setup.
                |     Each of these geometries may be either a Product or a
                |     Body.
                | 
                |     Parameters:
                | 
                |         oListOfFixtureGeometriesProducts
                |             The retrieved list.
                |             The array must be previously initialized using the
                |
                |         FixtureGeometriesCount method. 
                | 
                | Example:
                |     The following example retrieves the Fixture geometries list of the
                |     manufacturing setup CurrentSetup in
                |     ListOfFixtureGeometriesProducts.
                | 
                |      Dim CurrentSetup As ManufacturingSetup
                |      Set CurrentSetup = ...
                |      Dim FixtureGeometriesListSize As Long
                |      FixtureGeometriesListSize = CurrentSetup.FixtureGeometriesCount
                |      If FixtureGeometriesListSize > 0 Then
                |        Dim ListOfFixtureGeometries() As Variant
                |        Redim
                |        ListOfFixtureGeometries(FixtureGeometriesListSize-1)
                |       CurrentSetup.ListFixtureGeometriesProducts(ListOfFixtureGeometriesProducts)
                |      End If

        :param tuple o_list_of_fixture_geometries_products:
        :rtype: cat_variant
        """
        return self.manufacturing_setup.ListFixtureGeometriesProducts(o_list_of_fixture_geometries_products)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'list_fixture_geometries_products'
        # # vba_code = """
        # # Public Function list_fixture_geometries_products(manufacturing_setup)
        # #     Dim oListOfFixtureGeometriesProducts (2)
        # #     manufacturing_setup.ListFixtureGeometriesProducts oListOfFixtureGeometriesProducts
        # #     list_fixture_geometries_products = oListOfFixtureGeometriesProducts
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def list_in_process_model_bodies(self, o_list_of_ipm_bodies: tuple) -> cat_variant:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ListInProcessModelBodies(CATSafeArrayVariant
                | oListOfIPMBodies)
                | 
                |     Retrieves the In Process Model Bodies list from a Manufacturing
                |     Setup.
                | 
                |     Parameters:
                | 
                |         oListOfIPMBodies
                |             The retrieved list.
                |             The array must be previously initialized using the
                |
                |         InProcessModelBodiesCount method. 
                | 
                | Example:
                |     The following example retrieves the In Process Model Bodies list of the
                |     manufacturing setup CurrentSetup in ListOfIPMBodies.
                | 
                |      Dim CurrentSetup As ManufacturingSetup
                |      Set CurrentSetup = ...
                |      Dim IPMBodiesListSize As Long
                |      IPMBodiesListSize = CurrentSetup.InProcessModelBodiesCount
                |      If IPMBodiesListSize > 0 Then
                |        Dim ListOfIPMBodies() As Variant
                |        Redim ListOfIPMBodies(IPMBodiesListSize-1)
                |        CurrentSetup.ListInProcessModelBodies(ListOfIPMBodies)
                |      End If

        :param tuple o_list_of_ipm_bodies:
        :rtype: cat_variant
        """
        return self.manufacturing_setup.ListInProcessModelBodies(o_list_of_ipm_bodies)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'list_in_process_model_bodies'
        # # vba_code = """
        # # Public Function list_in_process_model_bodies(manufacturing_setup)
        # #     Dim oListOfIPMBodies (2)
        # #     manufacturing_setup.ListInProcessModelBodies oListOfIPMBodies
        # #     list_in_process_model_bodies = oListOfIPMBodies
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def list_stock_geometries(self, o_list_of_stock_geometries: tuple) -> cat_variant:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ListStockGeometries(CATSafeArrayVariant
                | oListOfStockGeometries)
                | 
                |     Retrieves the stock geometries list from a Manufacturing Setup. Each of
                |     these geometries may be either a Product or a Body.
                | 
                |     Parameters:
                | 
                |         oListOfStockGeometries
                |             The retrieved list.
                |             The array must be previously initialized using the
                |             
                | 
                |         StockGeometriesCount method. 
                | 
                | Example:
                |     The following example retrieves the stock geometries list of the
                |     manufacturing setup CurrentSetup in ListOfStockGeometries.
                | 
                |      Dim CurrentSetup As ManufacturingSetup
                |      Set CurrentSetup = ...
                |      Dim StockGeometriesListSize As Long
                |      StockGeometriesListSize = CurrentSetup.StockGeometriesCount
                |      If StockGeometriesListSize > 0 Then
                |        Dim ListOfStockGeometries() As Variant
                |        Redim ListOfStockGeometries(StockGeometriesListSize-1)
                |        CurrentSetup.ListStockGeometries(ListOfStockGeometries)
                |      End If

        :param tuple o_list_of_stock_geometries:
        :rtype: cat_variant
        """
        return self.manufacturing_setup.ListStockGeometries(o_list_of_stock_geometries)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'list_stock_geometries'
        # # vba_code = """
        # # Public Function list_stock_geometries(manufacturing_setup)
        # #     Dim oListOfStockGeometries (2)
        # #     manufacturing_setup.ListStockGeometries oListOfStockGeometries
        # #     list_stock_geometries = oListOfStockGeometries
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def list_stock_geometries_products(self, o_list_of_stock_geometries_products: tuple) -> cat_variant:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ListStockGeometriesProducts(CATSafeArrayVariant
                | oListOfStockGeometriesProducts)
                | 
                |     Retrieves the Stock geometries products list from a Manufacturing Setup.
                |     Each of these geometries may be either a Product or a
                |     Body.
                | 
                |     Parameters:
                | 
                |         oListOfStockGeometriesProducts
                |             The retrieved list.
                |             The array must be previously initialized using the
                |
                |         StockGeometriesCount method. 
                | 
                | Example:
                |     The following example retrieves the Stock geometries list of the
                |     manufacturing setup CurrentSetup in
                |     ListOfStockGeometriesProducts.
                | 
                |      Dim CurrentSetup As ManufacturingSetup
                |      Set CurrentSetup = ...
                |      Dim StockGeometriesListSize As Long
                |      StockGeometriesListSize = CurrentSetup.StockGeometriesCount
                |      If StockGeometriesListSize > 0 Then
                |        Dim ListOfStockGeometries() As Variant
                |        Redim ListOfStockGeometries(StockGeometriesListSize-1)
                |       CurrentSetup.ListStockGeometriesProducts(ListOfStockGeometriesProducts)
                |      End If

        :param tuple o_list_of_stock_geometries_products:
        :rtype: cat_variant
        """
        return self.manufacturing_setup.ListStockGeometriesProducts(o_list_of_stock_geometries_products)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'list_stock_geometries_products'
        # # vba_code = """
        # # Public Function list_stock_geometries_products(manufacturing_setup)
        # #     Dim oListOfStockGeometriesProducts (2)
        # #     manufacturing_setup.ListStockGeometriesProducts oListOfStockGeometriesProducts
        # #     list_stock_geometries_products = oListOfStockGeometriesProducts
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def read_mfg_data(self, i_file_name: str, i_ncmillset: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ReadMfgData(CATBSTR iFileName,
                | CATSafeArrayVariant iNCMILLSET)
                | 
                |     ReadMfgData. Read Manufacturing V4 data.
                |     iFileName = Path for V4 product
                |     iNCMILLSET = NC sets Acts Same as command "Read Manufacturing data from V4 model"
                 |    in NC Manufacturing Review workbench Call on Current Manufacturngsetup


        :param str i_file_name:
        :param tuple i_ncmillset:
        :rtype: None
        """
        return self.manufacturing_setup.ReadMfgData(i_file_name, i_ncmillset)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'read_mfg_data'
        # # vba_code = """
        # # Public Function read_mfg_data(manufacturing_setup)
        # #     Dim iFileName (2)
        # #     manufacturing_setup.ReadMfgData iFileName
        # #     read_mfg_data = iFileName
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_design_part(self, i_part: AnyObject, i_product: Product) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetDesignPart(AnyObject iPart,
                | Product iProduct)
                | 
                |     Associates the design part to a Manufacturing Setup.
                |     The part must be a Body feature (Geometrical Set, Ordered Geometrical Set,
                |     PartBody, Body.n)
                | 
                |     Example:
                |         The following example associates the part iPart belonging to the
                |         Product iProduct to the manufacturing setup
                |         CurrentSetup
                | 
                |          call CurrentSetup.SetPart(iPart,iProduct)

        :param AnyObject i_part:
        :param Product i_product:
        :rtype: None
        """
        return self.manufacturing_setup.SetDesignPart(i_part.com_object, i_product.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_design_part'
        # # vba_code = """
        # # Public Function set_design_part(manufacturing_setup)
        # #     Dim iPart (2)
        # #     manufacturing_setup.SetDesignPart iPart
        # #     set_design_part = iPart
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_product_and_reconciliate(self, i_product: Product) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetProductAndReconciliate(Product iProduct)
                | 
                |     Associate the Product to a Manufacturing Setup and reconciliate
                |     links.
                | 
                |     Example:
                |         The following example associates the Product iProduct to the
                |         manufacturing setup CurrentSetup
                | 
                |          call CurrentSetup.SetProductAndReconciliate(iProduct)

        :param Product i_product:
        :rtype: None
        """
        return self.manufacturing_setup.SetProductAndReconciliate(i_product.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_product_and_reconciliate'
        # # vba_code = """
        # # Public Function set_product_and_reconciliate(manufacturing_setup)
        # #     Dim iProduct (2)
        # #     manufacturing_setup.SetProductAndReconciliate iProduct
        # #     set_product_and_reconciliate = iProduct
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_safety_plane(self, i_safety_plane: AnyObject, i_product: Product) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetSafetyPlane(AnyObject iSafetyPlane,
                | Product iProduct)
                | 
                |     Associates a Safety Plane to a Manufacturing Setup.
                | 
                |     Example:
                |         The following example associates the Safety Plane iSafetyPlane
                |         belonging to the Product iProduct to the manufacturing setup
                |         CurrentSetup
                | 
                |          call
                |          CurrentSetup.SetSafetyPlane(iSafetyPlane,iProduct)

        :param AnyObject i_safety_plane:
        :param Product i_product:
        :rtype: None
        """
        return self.manufacturing_setup.SetSafetyPlane(i_safety_plane.com_object, i_product.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_safety_plane'
        # # vba_code = """
        # # Public Function set_safety_plane(manufacturing_setup)
        # #     Dim iSafetyPlane (2)
        # #     manufacturing_setup.SetSafetyPlane iSafetyPlane
        # #     set_safety_plane = iSafetyPlane
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_stock(self, i_stock: AnyObject, i_product: Product) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetStock(AnyObject iStock,
                | Product iProduct)
                | 
                |     Associates a stock to a Manufacturing Setup.
                |     The stock must be either a Body feature (Geometrical Set, Ordered
                |     Geometrical Set, PartBody, Body.n) either a CGR product.
                | 
                |     Example:
                |         The following example associates the stock iStock belonging to the
                |         Product iProduct to the manufacturing setup
                |         CurrentSetup
                | 
                |          call CurrentSetup.SetStock(iStock,iProduct)

        :param AnyObject i_stock:
        :param Product i_product:
        :rtype: None
        """
        return self.manufacturing_setup.SetStock(i_stock.com_object, i_product.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_stock'
        # # vba_code = """
        # # Public Function set_stock(manufacturing_setup)
        # #     Dim iStock (2)
        # #     manufacturing_setup.SetStock iStock
        # #     set_stock = iStock
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_tool_change_point(self, i_x: float, i_y: float, i_z: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetToolChangePoint(double iX,
                | double iY,
                | double iZ)
                | 
                |     Initialise the ToolChange point of the machine linked to a Manufacturing
                |     Setup.
                | 
                |     Example:
                |         The following example initialise the point with coordinates X,Y,Z as
                |         ToolChangePoint in the manufacturing setup
                |         CurrentSetup
                | 
                |          call CurrentSetup.SetToolChangePoint(X,Y,Z)

        :param float i_x:
        :param float i_y:
        :param float i_z:
        :rtype: None
        """
        return self.manufacturing_setup.SetToolChangePoint(i_x, i_y, i_z)

    def set_tool_change_point_by_name(self, i_point_name: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetToolChangePointByName(CATBSTR iPointName)
                | 
                |     Initialise the ToolChange point of the machine linked to a Manufacturing
                |     Setup.
                | 
                |     Example:
                |         The following example initialise the point PT23 as ToolChangePoint in
                |         the manufacturing setup CurrentSetup
                | 
                |          call CurrentSetup.SetToolChangePointByName(PT23)

        :param str i_point_name:
        :rtype: None
        """
        return self.manufacturing_setup.SetToolChangePointByName(i_point_name)

    def stock_geometries_count(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func StockGeometriesCount() As long
                | 
                |     Returns the number of stock geometries from a Manufacturing
                |     Setup.
                | 
                |     Parameters:
                | 
                |         oStockGeometriesListSize
                |             The number of stock geometries of this setup 
                | 
                |     Example:
                |         The following example retrieves the number of stock geometries of the
                |         setup CurrentSetup in StockGeometriesListSize.
                | 
                |          Dim CurrentSetup As ManufacturingSetup
                |          Set CurrentSetup = ...
                |          Dim StockGeometriesListSize As Long
                |          StockGeometriesListSize = CurrentSetup.StockGeometriesCount

        :rtype: int
        """
        return self.manufacturing_setup.StockGeometriesCount()

    def __repr__(self):
        return f'ManufacturingSetup(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.reference import Reference
from pycatia.mec_mod_interfaces.hybrid_shape import HybridShape


class HybridShapeAxisToAxis(HybridShape):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.HybridShape
                |                         HybridShapeAxisToAxis
                | 
                | Represents the hybrid shape axis to axis transformation feature
                | object.
                | Role: To access the data of the axis to axis transformation shape feature
                | object. The data includes:
                | 
                |     The element to be transformed
                |     The reference axis system
                |     The target axis system
                | 
                | LICENSING INFORMATION: Creation of volume result requires GSO
                | License
                | if GSO License is not granted , setting of Volume context has not
                | effect
                | Use the CATIAHybridShapeFactory to create HybridShapeFeature
                | object.
                | 
                | See also:
                |     HybridShapeFactory
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.hybrid_shape_axis_to_axis = com_object

    @property
    def creation_mode(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property CreationMode() As boolean
                | 
                |     Returns or sets the creation mode(creation or
                |     modification).
                |     Legal values: True if the result is a creation feature and False if the
                |     result is a modification feature.
                | 
                |     Example:
                | 
                |           This example sets that the mode of
                |          the hybShpAxisToAxis hybrid shape axis to axis to
                |          creation
                |          
                | 
                |          hybShpAxisToAxis.CreationMode = True

        :rtype: bool
        """

        return self.hybrid_shape_axis_to_axis.CreationMode

    @creation_mode.setter
    def creation_mode(self, value: bool):
        """
        :param bool value:
        """

        self.hybrid_shape_axis_to_axis.CreationMode = value

    @property
    def elem_to_transform(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property ElemToTransform() As Reference
                | 
                |     Returns or sets the element to transform.
                | 
                |     Example:
                |         This example retrieves in Elem the element to transform for the
                |         AxisToAxis hybrid shape feature.
                | 
                |          Dim Elem As Reference
                |          Set Elem = AxisToAxis.ElemToTransform

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_axis_to_axis.ElemToTransform)

    @elem_to_transform.setter
    def elem_to_transform(self, value: Reference):
        """
        :param Reference value:
        """

        self.hybrid_shape_axis_to_axis.ElemToTransform = value.com_object

    @property
    def reference_axis(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property ReferenceAxis() As Reference
                | 
                |     Returns or sets the reference axis.
                | 
                |     Example:
                |         This example retrieves in Ref the reference axis for the AxisToAxis
                |         hybrid shape feature.
                | 
                |          Dim Ref As Reference
                |          Set Ref = AxisToAxis.ReferenceAxis

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_axis_to_axis.ReferenceAxis)

    @reference_axis.setter
    def reference_axis(self, value: Reference):
        """
        :param Reference value:
        """

        self.hybrid_shape_axis_to_axis.ReferenceAxis = value.com_object

    @property
    def target_axis(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property TargetAxis() As Reference
                | 
                |     Returns or sets the target axis.
                | 
                |     Example:
                |         This example retrieves in Ref the target axis for the AxisToAxis hybrid
                |         shape feature.
                | 
                |          Dim Ref As Reference
                |          Set Ref = AxisToAxis.ReferenceAxis

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_axis_to_axis.TargetAxis)

    @target_axis.setter
    def target_axis(self, value: Reference):
        """
        :param Reference value:
        """

        self.hybrid_shape_axis_to_axis.TargetAxis = value.com_object

    @property
    def volume_result(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property VolumeResult() As boolean
                | 
                |     Returns or sets the volume result.
                |     Legal values: True if the result of axis to axis transformation is required
                |     as volume (option is effective only in case of volumes,requires GSO License))
                |     and False if it is needed as surface .
                | 
                |     Example:
                | 
                |           This example sets that the result of
                |          the hybShpAxisToAxis hybrid shape AxisToAxis is
                |          volume.
                |          
                | 
                |          hybShpAxisToAxis.VolumeResult = True

        :rtype: bool
        """

        return self.hybrid_shape_axis_to_axis.VolumeResult

    @volume_result.setter
    def volume_result(self, value: bool):
        """
        :param bool value:
        """

        self.hybrid_shape_axis_to_axis.VolumeResult = value

    def __repr__(self):
        return f'HybridShapeAxisToAxis(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.structure_interfaces.str_plate import StrPlate
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class StrPlates(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     StrPlates
                | 
                | A collection of the Plate objects contained in a given Product object of a
                | ProductDocument object.
                | A Product object can aggregate one or zero Plates collection. This collection
                | is retrieved using the Product.GetTechnologicalObject method of the
                | product.
                | 
                | Example:
                |     The following example retrieves the plate collection from the oProduct
                |     Product.
                | 
                |      Dim oPlates as AnyObject
                |      Set oPlates = oProduct.GetTechnologicalObject("StructurePlates")
                |      
                | 
                |     Method Index
                |     Item
                |         Returns a plate from its index in the Plates collection.
                |         
                |     Remove
                |         Removes a plate from the Plates collection. 
                | 
                |     Methods
                | 
                | o Func Item(	CATVariant 	iIndex) As StrPlate
                | 
                |     Returns a plate from its index in the Plates collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index of the plate to retrieve in the collection of plates.
                |             This index can either be the rank of the plate in the collection or the name
                |             you assign to the plate. As a numerics, this index is the rank of the plate in
                |             the collection. The index of the first plate in the collection is 1, and the
                |             index of the last plate is Count. As a string, it is the name you assigned to
                |             the plate using the 
                | 
                |         AnyObject.Name property 
                |     Returns:
                |         The retrieved plate
                | 
                |         Example:
                |             The following example returns in ThisPlate the third plate, and in
                |             ThatPlate the plate named EndPlate_1 in the Assembly_1 plate
                |             collection.
                | 
                |              Dim ThisPlate As Plate
                |              Set ThisPlate = Assembly_1.Item(3)
                |              Dim ThatPlate As Plate
                |              Set ThatPlate = Assembly.Item("EndPlate_1")
                |              
                | 
                | o Sub Remove(	CATVariant 	iIndex)
                | 
                |     Removes a plate from the Plates collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index of the plate to remove. This index can either be the rank
                |             of the plate in the collection or the name you assigned to the plate. As a
                |             numerics, this index is the rank of the plate in the collection. The index of
                |             the first plate in the collection is 1, and the index of the last plate is
                |             Count. As a string, it is the name you assigned to the plate using the
                |             
                | 
                |         AnyObject.Name property
                | 
                |         Example:
                |             The following example removes the sixth plate and the plate named
                |             EndPlate_1 from the Assembly_1 plate collection.
                | 
                |              Assembly_1.Remove(6)
                |              Assembly_1.Remove("EndPlate_1")
                |              
                | 
                | Copyright © 1999-2011, Dassault Systèmes. All rights reserved.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=StrPlate)
        self.str_plates = com_object

    def item(self, i_index: cat_variant) -> StrPlate:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(CATVariant iIndex) As StrPlate
                | 
                |     Returns a plate from its index in the Plates collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index of the plate to retrieve in the collection of plates.
                |             This index can either be the rank of the plate in the collection or the name
                |             you assign to the plate. As a numerics, this index is the rank of the plate in
                |             the collection. The index of the first plate in the collection is 1, and the
                |             index of the last plate is Count. As a string, it is the name you assigned to
                |             the plate using the 
                | 
                |         AnyObject.Name property 
                |     Returns:
                |         The retrieved plate
                | 
                |         Example:
                |             The following example returns in ThisPlate the third plate, and in
                |             ThatPlate the plate named EndPlate_1 in the Assembly_1 plate
                |             collection.
                | 
                |              Dim ThisPlate As Plate
                |              Set ThisPlate = Assembly_1.Item(3)
                |              Dim ThatPlate As Plate
                |              Set ThatPlate = Assembly.Item("EndPlate_1")

        :param cat_variant i_index:
        :rtype: StrPlate
        """
        return StrPlate(self.str_plates.Item(i_index))

    def remove(self, i_index: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Remove(CATVariant iIndex)
                | 
                |     Removes a plate from the Plates collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index of the plate to remove. This index can either be the rank
                |             of the plate in the collection or the name you assigned to the plate. As a
                |             numerics, this index is the rank of the plate in the collection. The index of
                |             the first plate in the collection is 1, and the index of the last plate is
                |             Count. As a string, it is the name you assigned to the plate using the
                |             
                | 
                |         AnyObject.Name property
                | 
                |         Example:
                |             The following example removes the sixth plate and the plate named
                |             EndPlate_1 from the Assembly_1 plate collection.
                | 
                |              Assembly_1.Remove(6)
                |              Assembly_1.Remove("EndPlate_1")

        :param cat_variant i_index:
        :rtype: None
        """
        return self.str_plates.Remove(i_index)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove'
        # # vba_code = """
        # # Public Function remove(str_plates)
        # #     Dim iIndex (2)
        # #     str_plates.Remove iIndex
        # #     remove = iIndex
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'StrPlates(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.in_interfaces.reference import Reference
from pycatia.system_interfaces.any_object import AnyObject


class SFMOpening(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SfmOpening
                | 
                | Defines Edition Techniques for Openings created using sketch and 3D
                | Object.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sfm_opening = com_object

    @property
    def creation_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property CreationMode(long iMode)
                | 
                |     Returns or Sets the Opening Creation Mode. 0 for 3D Mode. 1 for Sketch
                |     Mode. 2 for StandardOpening Mode.
                | 
                |     Example:
                |         This example gets the Creation Mode for existing
                |         Opening.
                | 
                |          'Get the Existing Opening
                |          Dim OpeningPlate As SfmOpening
                |          Set OpeningPlate = part1.FindObjectByName("Opening_028")
                |          Dim Sel As Selection
                |          Set Sel = CATIA.ActiveDocument.Selection
                |          Sel.Add OpeningPlate 
                |          Dim OpenFact As SfmOpening
                |          Set OpenFact = Sel.FindObject("CATIASfmOpening")
                |          Dim CreationMode As Long
                |          CreationMode = OpenFact.CreationMode

        :rtype: int
        """

        return self.sfm_opening.CreationMode

    @creation_mode.setter
    def creation_mode(self, value: int):
        """
        :param int value:
        """

        self.sfm_opening.CreationMode = value

    @property
    def direction(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Direction(Reference iDirection)
                | 
                |     Returns or Sets the Direction for a Wire Element Case.
                | 
                |     Example:
                |         This example modifies the direction of existing
                |         opening.
                | 
                |          'Get the element to be used as direction element.
                |          Set Dir = part1.FindObjectByName("Line.4")
                |          Set DirRef = part1.CreateReferenceFromObject(Dir)
                |          Opening1.Direction = DirRef

        :rtype: Reference
        """

        return self.sfm_opening.Direction

    @direction.setter
    def direction(self, value: Reference):
        """
        :param Reference value:
        """

        self.sfm_opening.Direction = value.com_object

    @property
    def intersecting_element(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property IntersectingElement(Reference
                | iIntersectingElement)
                | 
                |     Returns or Sets the Intersecting Element to Create a
                |     Opening.
                | 
                |     Example:
                |         This example sets the intersecting element for the existing opening,
                |         after changing it's mode to sketch mode.
                | 
                |          'Get the Creation Mode for Existing Opening. The Existing Opening is
                |          created using 3D Mode.
                |           CreationMode = Opening1.CreationMode
                |          'Set the Creation Mode for Existing Opening to sketch
                |          mode
                |          Opening1.CreationMode = 1
                |          'Assign a new sketch to the existing opening
                |          Set Sketch = part1.FindObjectByName("Sketch.4")
                |          Set sketchref = part1.CreateReferenceFromObject(Sketch)
                |          Opening1.IntersectingElement = sketchref

        :rtype: Reference
        """

        return self.sfm_opening.IntersectingElement

    @intersecting_element.setter
    def intersecting_element(self, value: Reference):
        """
        :param Reference value:
        """

        self.sfm_opening.IntersectingElement = value.com_object

    @property
    def molded_surface(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property MoldedSurface(Reference iMoldedSurface)
                | 
                |     Returns or Sets the Molded Surface for the Opening.
                | 
                |     Example:
                |         This example modifies the molded surface for the existing
                |         opening.
                | 
                |          'Get the Surface to be used as molded surface for the
                |          opening
                |          Dim GSDSurf As Reference
                |          Set GSDSurf = part1.FindObjectByName("Fill.1")
                |          Set GSDSurfref = part1.CreateReferenceFromObject(GSDSurf)
                |          Opening1.MoldedSurface = GSDSurfref

        :rtype: Reference
        """

        return self.sfm_opening.MoldedSurface

    @molded_surface.setter
    def molded_surface(self, value: Reference):
        """
        :param Reference value:
        """

        self.sfm_opening.MoldedSurface = value.com_object

    def get_direction(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetDirection() As CATSafeArrayVariant
                | 
                |     Gets the Direction for Opening in the form of Vector.
                | 
                |     Parameters:
                | 
                |         oDirection
                |             [out] Direction vector 
                | 
                |     Returns:
                |         S_OK if everything ran ok
                | 
                |         Example:
                |             This Example Gets the Direction for the Opening.
                | 
                |              Dim Dir() As Variant
                |              Dir = OpeningPlate.GetDirection
                |              Dim x, y, z As Double
                |              x = Dir(0)
                |              y = Dir(1)
                |              z = Dir(2)

        :rtype: tuple
        """
        return self.sfm_opening.GetDirection()

    def is_a_plate_opening(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func IsAPlateOpening() As long
                | 
                |     Determines if it is a Plate Opening or a Profile one.
                | 
                |     Parameters:
                | 
                |         oStatus
                |             [out] oStatus=0, if the Opening is on Plate oStatus=1, if the
                |             Opening is Not on Plate 
                | 
                |     Returns:
                |         S_OK if everything ran ok
                | 
                |         Example:
                |             This Example Checks weather the opening is a Plate
                |             Opening.
                | 
                |              'Get the Existing Opening in the Part Document
                |              Dim OpeningPlate As SfmOpening
                |              Set OpeningPlate = part1.FindObjectByName("Opening_028")
                |              Dim Sel As Selection
                |              Set Sel = CATIA.ActiveDocument.Selection
                |              Sel.Add OpeningPlate 
                |              Dim OpenFact As SfmOpening
                |              Set OpenFact = Sel.FindObject("CATIASfmOpening")
                |              'Get the Status of Opening
                |              Dim status As Long
                |              status = OpenFact.IsAPlateOpening

        :rtype: int
        """
        return self.sfm_opening.IsAPlateOpening()

    def set_master_mode(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetMasterMode()
                | 
                |     Sets Master mode on Copy Pasted Opening. It breaks the dependency by
                |     duplicating the sketch.
                | 
                |     Returns:
                |         S_OK if everything ran ok
                | 
                |         Example:
                |             This Example Sets Master Mdoe on a Copy Pasted
                |             Opening.
                | 
                |              Dim OpeningMaster As SfmOpening
                |              Set OpeningMaster = part1.FindObjectByName("Opening_035")
                |              Dim Sel As Selection
                |              Set Sel = CATIA.ActiveDocument.Selection
                |              Sel.Add OpeningMaster 
                |              Dim OpenFact As SfmOpening
                |              Set OpenFact = Sel.FindObject("CATIASfmOpening")
                |              OpenFact.SetMasterMode

        :rtype: None
        """
        return self.sfm_opening.SetMasterMode()

    def __repr__(self):
        return f'SFMOpening(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class SFMWeld(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SfmWeld
                | 
                | Interface to manage the Structure Functional Modeler Weld
                | object.
                | Role: Provides access to each Weld object's attributes.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sfm_weld = com_object

    @property
    def added_material(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AddedMaterial() As CATBSTR (Read Only)
                | 
                |     Gets Added Material.
                | 
                |     Parameters:
                | 
                |         oAddedMaterial
                |             [out] The retrieved Added Material. 
                | 
                |     Returns:
                |         S_OK if everything ran ok.
                | 
                |         Example:
                |             This example gets Weld Feature.
                | 
                |              Dim EachWeld As SfmWeld
                |              ustrAddedMaterial = EachWeld.AddedMaterial
                |              Next

        :rtype: str
        """

        return self.sfm_weld.AddedMaterial

    @property
    def edge_preparation(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property EdgePreparation() As CATBSTR (Read Only)
                | 
                |     Gets Edge Preparation.
                | 
                |     Parameters:
                | 
                |         oEdgePreparation
                |             [out] The retrieved Edge Preparation. 
                | 
                |     Returns:
                |         S_OK if everything ran ok.
                | 
                |         Example:
                |             This example gets Weld Feature.
                | 
                |              Dim EachWeld As SfmWeld
                |              ustrEdgePrep = EachWeld.EdgePreparation
                |              Next

        :rtype: str
        """

        return self.sfm_weld.EdgePreparation

    @property
    def fit_up(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property FitUp() As CATBSTR (Read Only)
                | 
                |     Gets Fit Up.
                | 
                |     Parameters:
                | 
                |         oFitUp
                |             [out] The retrieved Fit Up. 
                | 
                |     Returns:
                |         S_OK if everything ran ok.
                | 
                |         Example:
                |             This example gets Weld Feature.
                | 
                |              Dim EachWeld As SfmWeld
                |              ustrFitUp = EachWeld.FitUp
                |              Next

        :rtype: str
        """

        return self.sfm_weld.FitUp

    @property
    def weld_type(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property WeldType() As CATBSTR (Read Only)
                | 
                |     Gets Weld Type.
                | 
                |     Parameters:
                | 
                |         oWeldType
                |             [out] The retrieved Weld Type. 
                | 
                |     Returns:
                |         S_OK if everything ran ok.
                | 
                |         Example:
                |             This example gets Weld Feature.
                | 
                |              Dim ListWelds As SfmWelds
                |              Set ListWelds = SplitPlate.GetWelds(Nothing)
                |              Dim WeldFeature As SfmWeld
                |              Set WeldFeature = ListWelds.Item(1)
                |              Dim EachWeld As SfmWeld
                |              ustrWeldType = EachWeld.WeldType
                |              Next

        :rtype: str
        """

        return self.sfm_weld.WeldType

    def __repr__(self):
        return f'SFMWeld(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from typing import TYPE_CHECKING

from pycatia.system_interfaces.any_object import AnyObject

if TYPE_CHECKING:
    from pycatia.dnb_robot_interfaces.rob_generic_controller import RobGenericController


class GenericToolProfile(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     GenericToolProfile
                | 
                | Interface to manage Generic Tool Profile of Robot controller.
                | 
                | Role: This interface provides methods to get/set data related to Tool
                | Profile.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.generic_tool_profile = com_object

    def get_centroid(self, cx: float, cy: float, cz: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetCentroid(double cx,
                | double cy,
                | double cz)
                | 
                |     Retrieve the underlying x,y,z of the Tool centroid.
                | 
                |     Parameters:
                | 
                |         cx,
                |             The out parameter contains X Coordinate of the Tool centroid.
                |             
                |         cy,
                |             The out parameter contains Y Coordinate of the Tool centroid.
                |             
                |         cz,
                |             The out parameter contains Z Coordinate of the Tool centroid.
                |             
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param float cx:
        :param float cy:
        :param float cz:
        :rtype: None
        """
        return self.generic_tool_profile.GetCentroid(cx, cy, cz)

    def get_controller(self, o_controller: 'RobGenericController') -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetController(RobGenericController oController)
                | 
                |     Retrieves controller owning the profile.
                | 
                |     Parameters:
                | 
                |         oController
                |             This parameter contains pointer to controller. 
                | 
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param RobGenericController o_controller:
        :rtype: None
        """
        return self.generic_tool_profile.GetController(o_controller.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_controller'
        # # vba_code = """
        # # Public Function get_controller(generic_tool_profile)
        # #     Dim oController (2)
        # #     generic_tool_profile.GetController oController
        # #     get_controller = oController
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_inertia(self, ixx: float, iyy: float, izz: float, ixy: float, iyz: float, izx: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetInertia(double Ixx,
                | double Iyy,
                | double Izz,
                | double Ixy,
                | double Iyz,
                | double Izx)
                | 
                |     Get the underlying coefficient of the tool inertia.
                | 
                |     Parameters:
                | 
                |         Ixx,
                |             The Ixx coefficient. 
                |         Iyy,
                |             The Ixx coefficient. 
                |         Izz,
                |             The Ixx coefficient. 
                |         Ixy,
                |             The Ixx coefficient. 
                |         Iyz,
                |             The Ixx coefficient. 
                |         Izx,
                |             The Ixx coefficient. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param float ixx:
        :param float iyy:
        :param float izz:
        :param float ixy:
        :param float iyz:
        :param float izx:
        :rtype: None
        """
        return self.generic_tool_profile.GetInertia(ixx, iyy, izz, ixy, iyz, izx)

    def get_mass(self, mass: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetMass(double mass)
                | 
                |     Retrieves the mass of the tool.
                | 
                |     Parameters:
                | 
                |         mass
                |             This out parameter contains mass of the tool. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param float mass:
        :rtype: None
        """
        return self.generic_tool_profile.GetMass(mass)

    def get_name(self, o_name: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetName(CATBSTR oName)
                | 
                |     Gets name of the Tool Profile.
                | 
                |     Parameters:
                | 
                |         oName
                |             Name of the required Tool Profile. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param str o_name:
        :rtype: None
        """
        return self.generic_tool_profile.GetName(o_name)

    def get_tcp_offset(self, x: float, y: float, z: float, roll: float, pitch: float, yaw: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetTCPOffset(double x,
                | double y,
                | double z,
                | double roll,
                | double pitch,
                | double yaw)
                | 
                |     Retrieve the underlying x,y,z, roll, pitch, yaw of the Tool TCP
                |     offset.
                | 
                |     Parameters:
                | 
                |         x,
                |             The out parameter contains X Coordinate. 
                |         y,
                |             The out parameter contains Y Coordinate. 
                |         z,
                |             The out parameter contains Z Coordinate. 
                |         roll,
                |             The out parameter contains roll Coordinate. 
                |         pitch,
                |             The out parameter contains pitch Coordinate. 
                |         yaw,
                |             The out parameter contains yaw Coordinate. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param float x:
        :param float y:
        :param float z:
        :param float roll:
        :param float pitch:
        :param float yaw:
        :rtype: None
        """
        return self.generic_tool_profile.GetTCPOffset(x, y, z, roll, pitch, yaw)

    def get_tool_mobility(self, o_mobile: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetToolMobility(boolean oMobile)
                | 
                |     Retrieves tool mobility.
                | 
                |     Parameters:
                | 
                |         oMobile
                |             This out parameter contains whether tool is mobiled.
                |             
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise
                |             .

        :param bool o_mobile:
        :rtype: None
        """
        return self.generic_tool_profile.GetToolMobility(o_mobile)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_tool_mobility'
        # # vba_code = """
        # # Public Function get_tool_mobility(generic_tool_profile)
        # #     Dim oMobile (2)
        # #     generic_tool_profile.GetToolMobility oMobile
        # #     get_tool_mobility = oMobile
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_centroid(self, cx: float, cy: float, cz: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetCentroid(double cx,
                | double cy,
                | double cz)
                | 
                |     Set the tool centroid of Profile.
                | 
                |     Parameters:
                | 
                |         cx,
                |             The X Coordinate of tool centroid. 
                |         cy,
                |             The Y Coordinate of tool centroid. 
                |         cz,
                |             The Z Coordinate of tool centroid. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param float cx:
        :param float cy:
        :param float cz:
        :rtype: None
        """
        return self.generic_tool_profile.SetCentroid(cx, cy, cz)

    def set_inertia(self, ixx: float, iyy: float, izz: float, ixy: float, iyz: float, izx: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetInertia(double Ixx,
                | double Iyy,
                | double Izz,
                | double Ixy,
                | double Iyz,
                | double Izx)
                | 
                |     Set the underlying coefficient of the tool inertia.
                | 
                |     Parameters:
                | 
                |         Ixx,
                |             The Ixx coefficient. 
                |         Iyy,
                |             The Ixx coefficient. 
                |         Izz,
                |             The Ixx coefficient. 
                |         Ixy,
                |             The Ixx coefficient. 
                |         Iyz,
                |             The Ixx coefficient. 
                |         Izx,
                |             The Ixx coefficient. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param float ixx:
        :param float iyy:
        :param float izz:
        :param float ixy:
        :param float iyz:
        :param float izx:
        :rtype: None
        """
        return self.generic_tool_profile.SetInertia(ixx, iyy, izz, ixy, iyz, izx)

    def set_mass(self, mass: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetMass(double mass)
                | 
                |     Set tool mass.
                | 
                |     Parameters:
                | 
                |         mass
                |             set mass of tool . 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param float mass:
        :rtype: None
        """
        return self.generic_tool_profile.SetMass(mass)

    def set_name(self, i_name: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetName(CATBSTR iName)
                | 
                |     Set name of the Tool Profile.
                | 
                |     Parameters:
                | 
                |         iName
                |             Name of the Tool Profile to be set. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param str i_name:
        :rtype: None
        """
        return self.generic_tool_profile.SetName(i_name)

    def set_tcp_offset(self, x: float, y: float, z: float, roll: float, pitch: float, yaw: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetTCPOffset(double x,
                | double y,
                | double z,
                | double roll,
                | double pitch,
                | double yaw)
                | 
                |     Set the underlying x,y,z, roll, pitch, yaw of the tool TCP
                |     offset.
                | 
                |     Parameters:
                | 
                |         x,
                |             The X Coordinate. 
                |         y,
                |             The Y Coordinate. 
                |         z,
                |             The Z Coordinate. 
                |         roll,
                |             The roll Coordinate. 
                |         pitch,
                |             The pitch Coordinate. 
                |         yaw,
                |             The yaw Coordinate. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param float x:
        :param float y:
        :param float z:
        :param float roll:
        :param float pitch:
        :param float yaw:
        :rtype: None
        """
        return self.generic_tool_profile.SetTCPOffset(x, y, z, roll, pitch, yaw)

    def set_tool_mobility(self, i_mobile: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetToolMobility(boolean iMobile)
                | 
                |     Set tool mobility.
                | 
                |     Parameters:
                | 
                |         iMobile
                |             set whether tool is mobile or not. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise

        :param bool i_mobile:
        :rtype: None
        """
        return self.generic_tool_profile.SetToolMobility(i_mobile)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_tool_mobility'
        # # vba_code = """
        # # Public Function set_tool_mobility(generic_tool_profile)
        # #     Dim iMobile (2)
        # #     generic_tool_profile.SetToolMobility iMobile
        # #     set_tool_mobility = iMobile
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'GenericToolProfile(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.abq_automation_interfaces.abq_interaction import ABQInteraction
from pycatia.in_interfaces.reference import Reference
from pycatia.product_structure_interfaces.product import Product
from pycatia.product_structure_interfaces.publication import Publication


class ABQAnalyticalRigidSurface(ABQInteraction):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ABQAutomationItf.ABQInteraction
                |                         ABQAnalyticalRigidSurface
                | 
                | Represents an Abaqus Analytical rigid surface (ABQAnalyticalRigidSurface)
                | object.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.abq_analytical_rigid_surface = com_object

    @property
    def flip_side(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property FlipSide() As boolean
                | 
                |     Sets or returns the flip state for the ARS.

        :rtype: bool
        """

        return self.abq_analytical_rigid_surface.FlipSide

    @flip_side.setter
    def flip_side(self, value: bool):
        """
        :param bool value:
        """

        self.abq_analytical_rigid_surface.FlipSide = value

    def add_support_from_publication(self, i_product: Product, i_publication: Publication) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddSupportFromPublication(Product iProduct,
                | Publication iPublication)
                | 
                |     Adds a support to the Analytical rigid surface. If the support already
                |     exists, it is removed.
                | 
                |     Parameters:
                | 
                |         iProduct
                |             The CATIA Product specifying the object to which the rigid body
                |             constraint is applied.
                |         iPublication
                |             The CATIA Publication specifying the region to which the rigid body
                |             constraint is applied.
                | 
                |             Refer: CATIAPublication

        :param Product i_product:
        :param Publication i_publication:
        :rtype: None
        """
        return self.abq_analytical_rigid_surface.AddSupportFromPublication(i_product.com_object,
                                                                           i_publication.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_support_from_publication'
        # # vba_code = """
        # # Public Function add_support_from_publication(abq_analytical_rigid_surface)
        # #     Dim iProduct (2)
        # #     abq_analytical_rigid_surface.AddSupportFromPublication iProduct
        # #     add_support_from_publication = iProduct
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def add_support_from_reference(self, i_product: Product, i_ref: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddSupportFromReference(Product iProduct,
                | Reference iRef)
                | 
                |     Creates a new support for the Reference and adds it to the description of
                |     the Analysis Entity.
                | 
                |     Parameters:
                | 
                |         iProduct
                |             The CATIA Product specifying the positioning
                |             object.
                |         iSupport
                |             The CATIAReference specifying the object that is being pointed
                |             to.
                | 
                |             Refer: CATIAReference , CATIAProduct

        :param Product i_product:
        :param Reference i_ref:
        :rtype: None
        """
        return self.abq_analytical_rigid_surface.AddSupportFromReference(i_product.com_object, i_ref.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_support_from_reference'
        # # vba_code = """
        # # Public Function add_support_from_reference(abq_analytical_rigid_surface)
        # #     Dim iProduct (2)
        # #     abq_analytical_rigid_surface.AddSupportFromReference iProduct
        # #     add_support_from_reference = iProduct
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_handler(self, i_product: Product, i_ref: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetHandler(Product iProduct,
                | Reference iRef)
                | 
                |     Set the handler for the Analytical rigid surface.
                | 
                |     Parameters:
                | 
                |         iProduct
                |             The CATIAProduct specifying the positioning
                |             object.
                |         iRef
                |             The CATIAReference specifying the object that is being pointed
                |             to.

        :param Product i_product:
        :param Reference i_ref:
        :rtype: None
        """
        return self.abq_analytical_rigid_surface.SetHandler(i_product.com_object, i_ref.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_handler'
        # # vba_code = """
        # # Public Function set_handler(abq_analytical_rigid_surface)
        # #     Dim iProduct (2)
        # #     abq_analytical_rigid_surface.SetHandler iProduct
        # #     set_handler = iProduct
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_handler_from_publication(self, i_product: Product, i_publication: Publication) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetHandlerFromPublication(Product iProduct,
                | Publication iPublication)
                | 
                |     Sets the handler for the Analytical rigid surface. Any previously set
                |     handler will be replaced with the new value.
                | 
                |     Parameters:
                | 
                |         iProduct
                |             The CATIA Product for handeler.
                |         iPublication
                |             The CATIA Publication for handeler.
                | 
                |             Refer: CATIAPublication

        :param Product i_product:
        :param Publication i_publication:
        :rtype: None
        """
        return self.abq_analytical_rigid_surface.SetHandlerFromPublication(i_product.com_object,
                                                                           i_publication.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_handler_from_publication'
        # # vba_code = """
        # # Public Function set_handler_from_publication(abq_analytical_rigid_surface)
        # #     Dim iProduct (2)
        # #     abq_analytical_rigid_surface.SetHandlerFromPublication iProduct
        # #     set_handler_from_publication = iProduct
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'ABQAnalyticalRigidSurface(name="{self.name}")'
